@@ -295,6 +295,8 @@ class RefreshableBotoSession:
                     WebIdentityToken=self.session.bearer_token,
                     DurationSeconds=self.session_ttl,
                 ).get("Credentials")
+            else:
+                raise error
         # Token expire time logging
         bearer_expire_time = datetime.fromtimestamp(self.session.jwt["exp"]).strftime(
             "%H:%M:%S"
