@@ -86,12 +86,15 @@ def _generate_download_mapping(
         log.error("List download not implemented")
     else:
         # modes: file -> directory, directory -> directory
-        assert destination[-1] == "/", "Must point to a local directory"
+        assert destination[-1] == (
+            "/" if os.name == "posix" else "\\"
+        ), "Must point to a local directory"
         destination = pathlib.Path(destination).resolve()
         log.debug(f"destination: {destination}")
         # recursively list objects
+        object_root = s.parent if (s := pathlib.PurePosixPath(source)).suffix else s
         object_paths = {
-            pathlib.PurePosixPath(op.key.replace(source, ""))
+            pathlib.PurePosixPath(op.key).relative_to(object_root)
             for op in session.s3.Bucket(s3_bucket).objects.filter(Prefix=source)
         }
         log.debug(f"object_paths: {object_paths}")
@@ -112,7 +115,7 @@ def _generate_download_mapping(
         assert object_paths, "All files already exist locally."
         file_paths = [pathlib.Path(destination, op) for op in object_paths]
         log.debug(f"file_paths: {file_paths}")
-        object_paths = [pathlib.PurePosixPath(source, op) for op in object_paths]
+        object_paths = [pathlib.PurePosixPath(object_root, op) for op in object_paths]
 
     return object_paths, file_paths
 
@@ -206,7 +209,9 @@ def download_files(
     )
     log.info("Starting download")
     with tqdm.tqdm(
-        total=sum(session.s3.Object(s3_bucket, str(op)).content_length for op in object_paths),
+        total=sum(
+            session.s3.Object(s3_bucket, str(op)).content_length for op in object_paths
+        ),
         unit="B",
         unit_scale=True,
         desc="",
